braindecode.datautil.scale
==========================

.. currentmodule:: braindecode.datautil

.. autofunction:: scale

.. include:: braindecode.datautil.scale.examples

.. raw:: html

    <div style='clear:both'></div>